@@ -1,17 +1,8 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017
- *               Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgtextedit.h"
 
@@ -187,11 +178,7 @@ void KgpgTextEdit::slotEncode()
 		if (KGpgSettings::allowCustomEncryptionOptions()) {
 			const QString customoptions = dialog->getCustomOptions();
 			if (!customoptions.isEmpty())
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-				options << customoptions.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
 				options << customoptions.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 		}
 
 		if (KGpgSettings::pgpCompatibility())
@@ -311,7 +298,7 @@ void KgpgTextEdit::slotSignUpdate(int result)
 	const QString content = signt->signedText().join(lf) + lf;
 
     setPlainText(content);
-    emit resetEncoding(false);
+    Q_EMIT resetEncoding(false);
 }
 
 void KgpgTextEdit::slotVerifyDone(int result)
@@ -320,7 +307,7 @@ void KgpgTextEdit::slotVerifyDone(int result)
 	sender()->deleteLater();
 	Q_ASSERT(verify != nullptr);
 
-	emit verifyFinished();
+	Q_EMIT verifyFinished();
 
 	if (result == KGpgVerify::TS_MISSING_KEY) {
 		verifyKeyNeeded(verify->missingId());
