@@ -1,19 +1,10 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017
- *               Rolf Eike Beer <kde@opensource.sf-tec.de>
- * Copyright (C) 2011 Luis Ángel Fernández Fernández <laffdez@gmail.com>
- * Copyright (C) 2016 Andrius Štikonas <andrius@stikonas.eu>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2011 Luis Ángel Fernández Fernández <laffdez@gmail.com>
+    SPDX-FileCopyrightText: 2016 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "keysmanager.h"
 
@@ -422,13 +413,8 @@ KeysManager::KeysManager(QWidget *parent)
 	KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig().data(), "KeyView");
 	iview->restoreLayout(cg);
 
-#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 78, 0)
-	connect(photoProps, QOverload<int>::of(&KSelectAction::triggered), this, &KeysManager::slotSetPhotoSize);
-	connect(trustProps, QOverload<int>::of(&KSelectAction::triggered), this, &KeysManager::slotSetTrustFilter);
-#else
 	connect(photoProps, &KSelectAction::indexTriggered, this, &KeysManager::slotSetPhotoSize);
 	connect(trustProps, &KSelectAction::indexTriggered, this, &KeysManager::slotSetTrustFilter);
-#endif
 
 	QLabel *searchLabel = new QLabel(i18n("Search:"), this);
 	m_listviewsearch = new QLineEdit(this);
@@ -1199,7 +1185,7 @@ void KeysManager::showOptions()
 void KeysManager::readAllOptions()
 {
 	readOptions();
-	emit readAgainOptions();
+	Q_EMIT readAgainOptions();
 }
 
 void KeysManager::slotSetDefKey()
@@ -2736,11 +2722,7 @@ KeysManager::clipEncrypt()
 		QStringList options;
 
 		if (!dialog->getCustomOptions().isEmpty() && KGpgSettings::allowCustomEncryptionOptions())
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-			options = dialog->getCustomOptions().split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
 			options = dialog->getCustomOptions().split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
 		if (dialog->getUntrusted())
 			encOptions |= KGpgEncrypt::AllowUntrustedEncryption;
