@@ -1,17 +1,9 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2008,2009,2010,2011,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
- * Copyright (C) 2016 Andrius Štikoans <andrius@stikonas.eu>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2011, 2012, 2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2016 Andrius Štikoans <andrius@stikonas.eu>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgexternalactions.h"
 
@@ -105,11 +97,7 @@ void KGpgExternalActions::slotEncryptionKeySelected()
 		const QString customopts = dialog->getCustomOptions();
 
 		if (!customopts.isEmpty())
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-			opts << customopts.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
 			opts << customopts.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 	}
 
 	QStringList keys = dialog->selectedKeys();
@@ -185,11 +173,7 @@ void KGpgExternalActions::startFolderEncode()
 
 	QStringList selec = dialog->selectedKeys();
 	KGpgEncrypt::EncryptOptions encOptions = KGpgEncrypt::DefaultEncryption;
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-	const QStringList encryptOptions = dialog->getCustomOptions().split(QLatin1Char(' '),  QString::SkipEmptyParts);
-#else
 	const QStringList encryptOptions = dialog->getCustomOptions().split(QLatin1Char(' '),  Qt::SkipEmptyParts);
-#endif
 	if (dialog->getSymmetric()) {
 		selec.clear();
 	} else {
@@ -487,9 +471,9 @@ void KGpgExternalActions::slotSaveOptionsPath()
 	const QString defaultID(m_assistant->getDefaultKey());
 
 	KGpgSettings::self()->save();
-	emit updateDefault(defaultID);
+	Q_EMIT updateDefault(defaultID);
 	if (m_assistant->runKeyGenerate())
-		emit createNewKey();
+		Q_EMIT createNewKey();
 	m_assistant->deleteLater();
 }
 
