@@ -6,7 +6,7 @@
 
 class KGpgDecryptTest : public QObject {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testDecrypt();
 	void testDecrypt_data();
